function [x_approx, y_approx] = approx_distr(values, n_support)

% [x_approx, y_approx] = approx_distr(values, n_support)
% 
% Approximates an empirical distribution (a sample of sorted values) by a
% piecewise linear function.
%
% values -- empirical distribution, assumed to be sorted
% n_support -- number of supporting points for piecewise linear
%   approximation
% returns a vactor of x-coordinates and a vector of y-coordinates
%   specifying the supporting points of the pice-wise linear approximation
%   of the distribution given by values
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

ranks = [1:length(values)]./length(values);
x_approx = linspace(0,1,n_support); % x-values of supporting points
% compute y-values
y_approx(1)                = min(values);
y_approx(length(x_approx)) = max(values);
for i=2:length(x_approx)-1,
  idx = sum(ranks <= x_approx(i));
  alpha = (ranks(idx+1)-x_approx(i)) / (ranks(idx+1)-ranks(idx));
  y_approx(i) = alpha*values(idx) + (1-alpha)*values(idx+1);
end


%figure; hold on
%plot(linspace(0,1,length(values)),log2(values), 'k');
%plot(x_approx,log2(y_approx), '-*r');


