function perc = percentile(sample, k_percentile)

% perc = percentile(sample, k_percentile)
%
% Computes the k-th percentile of the given sample.
%
% sample -- a data vector of which to compute the percentile
% k_percentile -- specifies the percentile, e.g. 50 is equivalent to the
%   median
% returns the k-th percentile of the given sample 
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

x = sort(sample);
num_x = length(sample);
k = k_percentile/100 * (num_x-1) + 1;

[k_int, D] = rat(k);
if isequal(D,1),  % k is an integer, take percentile element
  perc = x(k_int);
else              % take midpoint between two elements
  perc = mean(x(floor(k):ceil(k)));
end

