function auc = plot_ROC(TP, FP, TN, FN, ah, colors)

% auc = plot_ROC(TP, FP, TN, FN, ah, colors)
%
% Plots one or more ROC curves and returns the AUC(s).
%
% ah -- optional axis handle to plot into
% colors -- optionally, colors for each graph can be specified
% returns the area under the ROC curve
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

assert(size(TP,1) == size(FP,1));
assert(size(TP,1) == size(TN,1));
assert(size(TP,1) == size(FN,1));
num_curves = size(TP,1);

if ~exist('colors', 'var'),
  c = colormap;
  colors = c(round(linspace(1,64,num_curves)),:);
end

hold on
for i=1:num_curves,
  % 1-Specificity
  % add a tiny bit to denominator to avoid division by 0
  FPR = FP(i,:)./(FP(i,:)+TN(i,:) + 10^-6);
  % Sensitivity (=Recall)
  % add a tiny bit to denominator to avoid division by 0
  TPR = TP(i,:)./(TP(i,:)+FN(i,:) + 10^-6);
  if exist('ah', 'var'),
    plot(ah, FPR, TPR, 'Color', colors(i,:), 'LineWidth', 2);
  else
    plot(FPR, TPR, 'Color', colors(i,:), 'LineWidth', 2);
  end
  % compute area under the curve
  FPR = FPR(end:-1:1);
  TPR = TPR(end:-1:1);
  assert(FPR(1)<0+10-5 & FPR(end)>1-10^-5);
  auc = area_trapz(FPR, TPR);
  if ~exist('ah', 'var'),
    th = text(0.7, 0.8-i*0.1, sprintf('AUC = %2.3f', auc));
    set(th, 'Color', colors(i,:));
  end
end
if exist('ah', 'var'),
  plot(ah, [0 1], [0 1], ':k');
  title(ah, 'ROC curve');
  xlabel(ah, '1 - specificity');
  ylabel(ah, 'sensitivity');
  axis(ah, [0 1 0 1]);
else
  plot([0 1], [0 1], ':k');
  title('ROC curve');
  xlabel('1 - specificity');
  ylabel('sensitivity');
  axis([0 1 0 1]);
end
