function values = reconstruct_distr(x_approx, y_approx, n)

% values = reconstruct_distr(x_approx, y_approx, n)
%
% Reconstructs an empirical distribution from a piecewise linear
% approximation.
%
% x_approx -- vector of x-coordinates of the piecewise linear
%   approximation
% y_approx -- vector of y-coordinates of the piecewise linear
%   approximation
% n -- the size of the sample (empirical distribution) to be
%   reconstructed
% returns the reconstructed distribution of n values
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

ranks = [1:n]/n;
values = zeros(size(ranks));

for i=1:n,
  idx = sum(x_approx < ranks(i));
  if idx<=0 || idx>=length(x_approx), keyboard; end
  alpha = (x_approx(idx+1) - ranks(i)) / (x_approx(idx+1) - x_approx(idx));
  values(i) = alpha*y_approx(idx) + (1-alpha)*y_approx(idx+1);
end

%figure; hold on
%plot(linspace(0,1,n),values, 'b');
%plot(x_approx,y_approx, '-*r');
