function [PM_I_mean MM_I_mean] = summ_replicates(PM_I, MM_I)

% [PM_I_mean MM_I_mean] = summ_replicates(PM_I, MM_I)
%
% Returns mean intensities per probe across replicate arrays.
%
% PM_I -- matrix of perfect match probe intensities (#replicates x #PM probes)
% MM_I -- optional matrix of mismatch probe intensities (#replicates x #MM probes)
% returns mean intensities for each probe across replicates. NaN is only
%   returned as mean intensity if all replicates for this probe are NaN.
%   MM_I_mean is only returned if MM_I was given as an argument
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

PM_I_mean = mean(PM_I); % take mean of replicates (ignoring NaN)
% correct probes for which at least one array has NaN
nan_idx = find(isnan(PM_I_mean));
PM_num_replic = nan(size(nan_idx));
for i=1:length(nan_idx),
  values = PM_I(:,nan_idx(i));
  values(isnan(values)) = [];
  PM_num_replic(i) = length(values);
  if isempty(values),
    PM_I_mean(i) = nan;
  else
    PM_I_mean(i) = mean(values);
  end
end
assert(~any(isnan(PM_num_replic)));
assert(all(0<=PM_num_replic & PM_num_replic<=3));
fprintf('  PM NaN in all 3 arrrays:     %7i\n', sum(PM_num_replic==0));
fprintf('  PM NaN in 2 of 3 arrrays:    %7i\n', sum(PM_num_replic==1));
fprintf('  PM NaN in 1 of 3 arrrays:    %7i\n', sum(PM_num_replic==2));
fprintf('  PM NaN in at least 1 arrray: %7i\n', length(PM_num_replic));

if exist('MM_I', 'var'),
  % take mean of replicates (ignoring NaN)
  MM_I_mean = mean(MM_I);
  nan_idx = find(isnan(MM_I_mean));
  MM_num_replic = nan(size(nan_idx));
  for i=1:length(nan_idx),
    values = MM_I(:,nan_idx(i));
    values(isnan(values)) = [];
    MM_num_replic(i) = length(values);
    if isempty(values),
      MM_I_mean(i) = nan;
    else
      MM_I_mean(i) = mean(values);
    end
  end
  assert(~any(isnan(MM_num_replic)));
  assert(all(0<=MM_num_replic & MM_num_replic<=3));
  fprintf('\n  MM NaN in all 3 arrrays:     %7i\n', sum(MM_num_replic==0));
  fprintf('  MM NaN in 2 of 3 arrrays:    %7i\n', sum(MM_num_replic==1));
  fprintf('  MM NaN in 1 of 3 arrrays:    %7i\n', sum(MM_num_replic==2));
  fprintf('  MM NaN in at least 1 arrray: %7i\n', length(MM_num_replic));
end