% Main script to start between-array quantile normalization as proposed
% in B.M. Bolstad et al., Bioinformatics (2003), A comparison of
% normalization methods for high density oligonucleotide array data based
% on variance and bias.
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

addpath ../common

%%% this can be adjusted to load files from a different location
data_dir = '../../PSB_data/array_data/';
%%% a suffix common to all input filenames
input_array_tag = 'A';
%%% the list of array file names to be included in quantile normalization
fnames = get_filenames(input_array_tag);

% read array data from .mat files if  existent, otherwise from .CEL files
for f=1:length(fnames),
  if ~fexist([data_dir fnames{f} '.mat']),
    fprintf('Parsing CEL file for %s...\n', fnames{f});
    arrays(f) = read_array_CEL([data_dir fnames{f} '.CEL']);
  else
    fprintf('Loading mat file for %s...\n', fnames{f});
    tmp = load([data_dir fnames{f} '.mat']);
    arrays(f) = tmp.array;
    clear tmp
  end
end

% perform quantile normalization
arrays = norm_quantiles(arrays);

% save output
for f=1:length(fnames),
  fname = [data_dir fnames{f} '_QN'];
  array = arrays(f);
  save([fname '.mat'], 'array');
%  write_array_plain([fname '.txt'], array, fnames, ...
%                    'CHIP_QUANTILE_NORMALIZATION');
end


