function array = read_array_CEL(fname)

% array = read_array_CEL(fname)
%
% Reads tiling array intensities from a .cel file returning a matlab struct.
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

state = 'N';
  
fprintf('\nParsing intensities from file %s\n', fname);
fd = fopen(fname, 'r');
if fd == -1,
  error(sprintf('file not found: %s', fname));
end

array.data_type = 'RAW_INTENSITIES';
cnt = 1;
cnt2 = 1;
tic
while ~feof(fd)
  line = fgetl(fd);
  if ~ischar(line),
    continue 
  end 
  switch state
   case 'N'
%    fprintf('N ');
    if strfind(line, 'HEADER'), 
      state = 'H'; 
    end
   case 'H'
%    fprintf('H ');
    if strfind(line, '[INTENSITY]'), 
      state = 'I'; 
    else
      if strfind(line, 'Cols='),
        array.num_cols = str2num(line(strfind(line,'=')+1:end));
      elseif strfind(line, 'Rows='), 
        array.num_rows = str2num(line(strfind(line,'=')+1:end));
      end
    end
   case 'I'
%    fprintf('I ');
    if strfind(line, '[MASKS]'),
      state = 'A'; 
    elseif strfind(line, 'NumberCells='),
      array.num_cells = str2num(line(strfind(line,'=')+1:end));
      assert(array.num_rows*array.num_cols == array.num_cells);
      array.mean       = -1*ones(array.num_rows,array.num_cols);
      array.stdv       = -1*ones(array.num_rows,array.num_cols);
      array.num_pixels = -1*ones(array.num_rows,array.num_cols);
      array.outliers   = zeros(array.num_rows,array.num_cols);
    elseif strfind(line, 'CellHeader='), 
     ; % do nothing
    else
      % parse intensities
      elems = splitstr(line);
      if length(elems)==5,
        X = str2num(elems{1})+1;
        Y = str2num(elems{2})+1;
        if equal(elems{3}, 'NA'),
          array.mean(X,Y)     = nan;
        else
          array.mean(X,Y)     = str2num(elems{3});
        end        
        array.stdv(X,Y)       = str2num(elems{4});
        array.num_pixels(X,Y) = str2num(elems{5});
        
        if mod(cnt,100000)==0,
          fprintf('parsed %i (of %i, %3.1f%%) intensity values in %2.0f secs...\r', ...
                  cnt, array.num_cells, ...
                  (100*cnt/(array.num_cells)), toc)
        end
        cnt = cnt + 1;
      end % else line is incomplete
    end
   case 'A'
%    fprintf('A ');
    if strfind(line, '[OUTLIERS]'),
      state = 'O';
      fprintf('\n')
    end
   case 'O'
%    fprintf('O ');
    if strfind(line, '[MODIFIED]'),
      state = 'M'; 
    elseif strfind(line, 'NumberCells='),
      array.num_outliers = str2num(line(strfind(line,'=')+1:end));
      tic
    elseif isempty(strfind(line, 'CellHeader=')), 
      % parse outliers
      elems = splitstr(line);
      if length(elems)==2,
        X = str2num(elems{1})+1;
        Y = str2num(elems{2})+1;

        array.outliers(X,Y) = 1;
        if mod(cnt2,1000)==0,
          fprintf('parsed %i (of %i, %3.1f%%) outliers in %2.0f secs...\r', ...
                  cnt2, array.num_outliers, (100*cnt2/array.num_outliers), toc)
        end
        cnt2 = cnt2+1;
      end
    end
   case 'M',
%    fprintf('O ');
  ; % do nothing
  end
end
fclose(fd);
e = strfind(fname, '.CEL');
fname = fname(1:e-1);
array.filename = fname;
fprintf('\n\nSaving to file %s\n', fname)
save([fname '.mat'], 'array');
