function fhandles = analyze_separability(intensities, probe_seq, probe_label, OPT)

% fhandles = analyze_separability(intensities, probe_seq, probe_label, OPT)
%
% Checks to which extent intensities of exonic probes are better
% separable after normalization.
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

print_dir = '../../PSB_data/norm_probe_results/figs/';

legends = {'raw intensities'};
I = intensities.PM_I;
colors = OPT.colormap.RAW;
if OPT.TEST_SVR, 
  legends{end+1} = 'SVR intensities';
  I(end+1,:) = intensities.PM_I_n_SVR; 
  colors = [colors; OPT.colormap.SVR];
end
if OPT.TEST_RR, 
  legends{end+1} = 'RR intensities';
  I(end+1,:) = intensities.PM_I_n_RR; 
  colors = [colors; OPT.colormap.RR];
end
if OPT.TEST_SQN,
  legends{end+1} = 'SQN intensities';
  I(end+1,:) = intensities.PM_I_n_SQN; 
  colors = [colors; OPT.colormap.SQN];
end
fhs = plot_sensitivity(I, probe_label, OPT.LABEL, legends, colors);
for f=1:length(fhs),
  fh = fhs(f);
  figure(fh);
  switch(f),
    case 1,
     fn = [print_dir 'separability_ROC.eps'];
     title('Intensity separation, ROC curve');
   case 2,
     fn = [print_dir 'separability_PrR.eps'];
     title('Intensity separation, PrR curve');
  end    
  print('-depsc', '-r300', fn);
end
fhandles = fhs;

% repeat with balanced GC content
gc_content = sum(probe_seq=='C' | probe_seq=='G', 1);
is_transcribed = (probe_label==OPT.LABEL.exonic);
is_not_transcribed = (probe_label==OPT.LABEL.intronic ...
                      | probe_label==OPT.LABEL.intergenic);
take_idx = zeros(1,length(gc_content));
for i=0:OPT.PROBE_LEN,
  idx1 = find(gc_content==i & is_transcribed);
  idx2 = find(gc_content==i & is_not_transcribed);
  sample_size = min([length(idx1) length(idx2)]);
  idx1 = idx1(randperm(length(idx1)));
  idx1 = idx1(1:sample_size);
  assert(all(take_idx(idx1) == 0));
  take_idx(idx1) = 1;
  idx2 = idx2(randperm(length(idx2)));
  idx2 = idx2(1:sample_size);
  assert(all(take_idx(idx2) == 0));
  take_idx(idx2) = 1;
end
take_idx = find(take_idx);
fhs = plot_sensitivity(I(:,take_idx), probe_label(take_idx), OPT.LABEL, ...
                       legends, colors);
for f=1:length(fhs),
  fh = fhs(f);
  figure(fh);
  switch(f),
    case 1,
     fn = [print_dir 'separability_ROC_GC_normalized.eps'];
     title('Intensity separation, ROC curve (GC normalized sample)');
   case 2,
     fn = [print_dir 'separability_PrR_GC_normalized.eps'];
     title('Intensity separation, PrR curve (GC normalized sample)');
  end    
  print('-depsc', '-r300', fn);
end
fhandles = [fhandles fhs];

