function fhandles = analyze_seq_effects(intensities, probe_seq, probe_label, OPT)

% fhandles = analyze_seq_effects(intensities, probe_seq, probe_label, OPT)
%
% Checks to which extent probe sequence effects disappeared in normalized
% intensities.
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

nucl_idx = struct;
for i=1:OPT.PROBE_LEN,
  nucl_idx(i).A = find(probe_seq(i,:)=='A');
  nucl_idx(i).C = find(probe_seq(i,:)=='C');
  nucl_idx(i).G = find(probe_seq(i,:)=='G');
  nucl_idx(i).T = find(probe_seq(i,:)=='T');
end
acgt = 'ACGT';
for i=1:OPT.PROBE_LEN-1,
  for j=1:length(acgt)^2,
    nt1 = ceil(j/length(acgt));
    nt2 = mod(j,length(acgt));
    if nt2==0, nt2 = length(acgt); end
    dint = [acgt(nt1) acgt(nt2)];
    idx1 = getfield(nucl_idx, {i}, acgt(nt1));
    idx2 = getfield(nucl_idx, {i+1}, acgt(nt2));
    nucl_idx = setfield(nucl_idx, {i}, dint, intersect(idx1, idx2));
  end
end
plot_gc_dependance(intensities.PM_I, probe_seq, 'raw I', probe_label, OPT.LABEL);
fhandles = gcf;

if ~OPT.TEST_SVR && ~OPT.TEST_SQN,
  plot_pos_quantile(intensities.PM_I, nucl_idx, OPT.PROBE_LEN, 50);
  plot_pos_quantile(intensities.PM_I, nucl_idx, OPT.PROBE_LEN, 90);
end

if OPT.TEST_SVR, 
  plot_gc_dependance(intensities.PM_I_n_SVR, probe_seq, 'SVR-normalized I', ...
                     probe_label, OPT.LABEL);
  fhandles = [fhandles gcf];
  
  [fh1 fh2] = plot_pos_quantile(intensities.PM_I, nucl_idx, OPT.PROBE_LEN, 50, 'RAW');
  fhandles = [fhandles fh1 fh2];
  print(fh1, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_RAW_plot.eps', 50));
  print(fh2, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_RAW_hmap.eps', 50));
  [fh1 fh2] = plot_pos_quantile(intensities.PM_I_n_SVR, nucl_idx, OPT.PROBE_LEN, 50, 'SVR');
  fhandles = [fhandles fh1 fh2];
  print(fh1, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_SVR_plot.eps', 50));
  print(fh2, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_SVR_hmap.eps', 50));

  [fh1 fh2] = plot_pos_quantile(intensities.PM_I, nucl_idx, OPT.PROBE_LEN, 90);
  fhandles = [fhandles fh1 fh2];
  print(fh1, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_RAW_plot.eps', 90));
  print(fh2, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_RAW_hmap.eps', 90));
  [fh1 fh2] = plot_pos_quantile(intensities.PM_I_n_SVR, nucl_idx, OPT.PROBE_LEN, 90, 'SVR');
  fhandles = [fhandles fh1 fh2];
  print(fh1, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_SVR_plot.eps', 90));
  print(fh2, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_SVR_hmap.eps', 90));
end
if OPT.TEST_RR, 
  plot_gc_dependance(intensities.PM_I_n_RR, probe_seq, 'RR-normalized I', ...
                     probe_label, OPT.LABEL);
  fhandles = [fhandles gcf];
  
  [fh1 fh2] = plot_pos_quantile(intensities.PM_I, nucl_idx, OPT.PROBE_LEN, 50, 'RAW');
  fhandles = [fhandles fh1 fh2];
  print(fh1, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_RAW_plot.eps', 50));
  print(fh2, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_RAW_hmap.eps', 50));
  [fh1 fh2] = plot_pos_quantile(intensities.PM_I_n_RR, nucl_idx, OPT.PROBE_LEN, 50, 'RR');
  fhandles = [fhandles fh1 fh2];
  print(fh1, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_RR_plot.eps', 50));
  print(fh2, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_RR_hmap.eps', 50));

  [fh1 fh2] = plot_pos_quantile(intensities.PM_I, nucl_idx, OPT.PROBE_LEN, 90);
  print(fh1, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_RAW_plot.eps', 90));
  print(fh2, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_RAW_hmap.eps', 90));
  [fh1 fh2] = plot_pos_quantile(intensities.PM_I_n_RR, nucl_idx, OPT.PROBE_LEN, 90, 'RR');
  print(fh1, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_RR_plot.eps', 90));
  print(fh2, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_RR_hmap.eps', 90));
end
if OPT.TEST_SQN, 
  fh = plot_gc_dependance(intensities.PM_I_n_SQN, probe_seq, 'SQN-normalized I', ...
                          probe_label, OPT.LABEL);
  fhandles = [fhandles gcf];
  
  [fh1 fh2] = plot_pos_quantile(intensities.PM_I, nucl_idx, OPT.PROBE_LEN, 50, 'RAW');
  fhandles = [fhandles fh1 fh2];
  print(fh2, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_SQN_plot.eps', 50));
  print(fh1, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_SQN_hmap.eps', 50));
  [fh1 fh2] = plot_pos_quantile(intensities.PM_I_n_SQN, nucl_idx, OPT.PROBE_LEN, 50,'SQN');
  fhandles = [fhandles fh1 fh2];
  print(fh1, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_SQN_plot.eps', 50));
  print(fh2, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_SQN_hmap.eps', 50));

  [fh1 fh2] = plot_pos_quantile(intensities.PM_I, nucl_idx, OPT.PROBE_LEN, 90);
  fhandles = [fhandles fh1 fh2];
  print(fh1, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_SQN_plot.eps', 90));
  print(fh2, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_SQN_hmap.eps', 90));
  [fh1 fh2] = plot_pos_quantile(intensities.PM_I_n_SQN, nucl_idx, OPT.PROBE_LEN, 90, 'SQN');
  fhandles = [fhandles fh1 fh2];
  print(fh, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_SQN_plot.eps', 90));
  print(fh, '-depsc', '-r300', sprintf('seq_vs_PM_perc%i_SQN_plot.eps', 90));
end

