function ret_fh = plot_sensitivity(I, probe_label, LABEL, legends, colors, fh)

% ret_fh = plot_sensitivity(I, probe_label, LABEL, [legends], [colors], [fh])
%
% Plots ROC and precision-recall curves for the global separation in
% intensity between exonic and intergenic/intronic probes.
%
% I -- an intensity matrix k x n for k different normalizations and n
%   probes
% probe_label -- a global annotation label for each probe
% LABEL -- a struct with all possible probe label constants
% legends -- labels for different normalization methods
% colors -- an option to specify the color for each curve
% fh -- a figure handle to plot into
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

if ~exist('colors', 'var'),
  colors = [0   0   0; ...
            0.8 0   0.3; ...
            0.0 0.8 0.3; ...
            0.3 0   0.8];
  
end

idx = 1:size(I,2);
for i=1:size(I,1),
  idx = intersect(idx, find(~isnan(I(i,:))));
end
label = zeros(1,length(idx));
label(probe_label(idx)==LABEL.exonic) = 1;
label(probe_label(idx)==LABEL.intergenic ...
      | probe_label(idx)==LABEL.intronic) = -1;
assert(length(label) == length(idx));

[TP FP TN FN] = eval_separation(I(:,idx), label);
  
% ROC curve
if exist('fh', 'var'),
  subplot(2,2,3);
  ret_fh = gcf;
else
  figure
  ret_fh = gcf;
end

AUC = plot_ROC(TP, FP, TN, FN, gca, colors);

switch length(legends),
 case 1,
  legend(legends{1}, 'Location', 'SouthEast');
 case 2,
  legend(legends{1}, legends{2}, 'Location', 'SouthEast');
 case 3,
  legend(legends{1}, legends{2}, legends{3}, 'Location', 'SouthEast');
end

% precision-recall curve
if exist('fh', 'var'),
  subplot(2,2,4);
else
  figure
  ret_fh = [ret_fh gcf];
end

AUC = plot_PrR(TP, FP, TN, FN, gca, colors);

switch length(legends),
 case 1,
  legend(legends{1}, 'Location', 'SouthWest');
 case 2,
  legend(legends{1}, legends{2}, 'Location', 'SouthWest');
 case 3,
  legend(legends{1}, legends{2}, legends{3}, 'Location', 'SouthWest');
end
