function SVM = predict_SVR(SVM);

% SVM = predict_SVR(SVM);
%
% Does the actual SVR prediction using the Shogun toolbox.
% (see http://www.shogun-toolbox.org/)
%
% SVM -- a struct corresponding to a trained SVM
% returns an SVM struct augmented by predicted intensity deviations
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

set_paths

if ~isfield(SVM, 'X_train_2'),
  fprintf('Deriving sequence properties (training data)...\n');
  sp = gen_seq_props(SVM.X_train_1);
  SVM.X_train_2 = [sp.gc_content; sp.entr; sp.hp_sc_1; sp.hp_sc_2];
end
if ~isfield(SVM, 'X_eval_2'),
  fprintf('Deriving sequence properties (validation data)...\n');
  sp = gen_seq_props(SVM.X_eval_1);
  SVM.X_eval_2 = [sp.gc_content; sp.entr; sp.hp_sc_1; sp.hp_sc_2];
end
  
%disp(SVM.PARAM)

sg('send_command', 'new_svm SVRLIGHT');
sg('send_command', 'use_linadd 1') ;
%sg('send_command', 'loglevel ALL');
sg('send_command', 'use_precompute 0');

sg('send_command','clean_features TRAIN') ;
sg('add_features','TRAIN', SVM.X_train_1, 'DNA');
sg('add_features','TRAIN', SVM.X_train_2);
sg('send_command', sprintf('set_kernel COMBINED %d', SVM.PARAM.cache_size));
sg('send_command', sprintf('add_kernel 1 WEIGHTEDDEGREEPOS3 CHAR 10 %i %i %i 1 %s', ...
                           SVM.PARAM.order, SVM.PARAM.wdk_mismatch, size(SVM.X_train_1,1), ...
                           sprintf('%i ', SVM.PARAM.wdk_shift_vec)));
sg('send_command', sprintf('add_kernel 1 LINEAR REAL 10'));

sg('set_labels', 'TRAIN', SVM.Y_train);
sg('send_command', 'init_kernel TRAIN');

sg('send_command', sprintf('c %f', SVM.PARAM.C));
sg('send_command', sprintf('svm_epsilon %f', SVM.PARAM.svm_eps));
sg('send_command', sprintf('svr_tube_epsilon %f', SVM.PARAM.tube));


% set SVM parameters determined in training
sg('set_svm', SVM.b, SVM.alphas);


% test error
sg('send_command','clean_features TEST') ;
sg('add_features','TEST', SVM.X_eval_1, 'DNA');
sg('add_features','TEST', SVM.X_eval_2);  
sg('send_command', 'init_kernel TEST');
SVM.Y_pred_eval = sg('svm_classify');  

