function kmers = seq_2_kmers(seq, order);

% kmers = seq_2_kmers(seq, order);
%
% Computes a matrix of positional occurrence counts of substrings in the
% given matrix of probe sequences.
%
% seq -- a matrix of probe sequences
% order -- maximal substring length
% returns a matrix with positional substring occurrences
%
% written by Georg Zeller, MPI Tuebingen, Germany, 2007-2008

assert(all(all(seq=='A' | seq=='C' | seq=='G' | seq=='T')));
% length of a single example sequence (aka PROBE_LEN)
s_len = size(seq,1);
offset = 0;
acgt = 'ACGT';
num_nt = length(acgt);
for o=1:order,
  offset(o+1) = offset(o) + (s_len-o+1) * num_nt^o;
end
kmer_dim = offset(end);

nucleotides{1} = acgt';
for o=2:order,
  nucleotides{o} = char(zeros(length(nucleotides{o-1}) * num_nt, o));
  for i=1:length(nucleotides{o-1}),
    for j=1:num_nt,
      row = (i-1) * num_nt + j;
      nucleotides{o}(row,:) = [nucleotides{o-1}(i,:) acgt(j)];
    end
  end
end

kmers = zeros(kmer_dim, size(seq,2));
for o=1:order,
  for i=1:s_len-o+1,
    for j=1:length(nucleotides{o});
      idx = strmatch(nucleotides{o}(j,:), seq(i:i+o-1,:)');
      row = offset(o) + (i-1)*num_nt^o + j;
      kmers(row,idx) = 1;
    end
%    fprintf('order=%i, pos=%2i   \r',o,i);
  end
end

exp_sum = 0;
for o=1:order,
  exp_sum = exp_sum + s_len-o+1;
end
assert(all(sum(kmers) == exp_sum));


